@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use autodie;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 # CPAN::Reporter spits out random output we don't want, and we don't want to
 # report these tests anyway.
@@ -36,7 +36,7 @@ $ENV{PERL_AUTOINSTALL}    = '--defaultdeps';
 $ENV{PERL_MM_USE_DEFAULT} = 1;
 ## use critic
 
-my $Test = Test::Builder->new();
+my $Test = Test::Builder->new;
 
 sub test_all_dependents {
     my $module = shift;
@@ -59,7 +59,7 @@ sub _get_deps {
 
     $module =~ s/::/-/g;
 
-    my $rev_deps = MetaCPAN::Client->new()->rev_deps($module);
+    my $rev_deps = MetaCPAN::Client->new->rev_deps($module);
 
     my $allow
         = $params->{filter} ? $params->{filter}
@@ -129,13 +129,13 @@ sub _test_in_parallel {
     );
 
     for my $module (@_) {
-        $pm->start() and next;
+        $pm->start and next;
 
         local $Test::Builder::Level = $Test::Builder::Level + 1;
         test_module( $module, $pm );
     }
 
-    $pm->wait_all_children();
+    $pm->wait_all_children;
 }
 
 sub test_module {
@@ -149,11 +149,13 @@ sub test_module {
 
     my $dist = _get_distro($name);
 
+    $Test->diag( 'Testing ' . $dist->base_id );
+
     unless ($dist) {
         $name =~ s/::/-/g;
         my $todo
-            = defined( $Test->todo() )
-            ? ' (TODO: ' . $Test->todo() . ')'
+            = defined( $Test->todo )
+            ? ' (TODO: ' . $Test->todo . ')'
             : q{};
         my $summary = "FAIL${todo}: $name - ??? - ???";
         my $output  = "Could not find $name on CPAN\n";
@@ -176,7 +178,7 @@ sub test_module {
         return;
     }
 
-    $name = $dist->base_id();
+    $name = $dist->base_id;
 
     my $success = try {
         capture { _install_prereqs($dist) };
@@ -205,7 +207,7 @@ sub test_module {
 
     return unless $success;
 
-    my ( $passed, $output, $stderr ) = _run_tests_for_dir( $dist->dir() );
+    my ( $passed, $output, $stderr ) = _run_tests_for_dir( $dist->dir );
 
     # A lot of modules seem to have cargo-culted a diag() that looks like this
     # ...
@@ -215,14 +217,12 @@ sub test_module {
         if defined $stderr && $stderr =~ /\A\# Testing [\w:]+ [^\n]+\Z/;
 
     my $status = $passed && $stderr ? 'WARN' : $passed ? 'PASS' : 'FAIL';
-    if ( my $reason = $Test->todo() ) {
+    if ( my $reason = $Test->todo ) {
         $status .= " (TODO: $reason)";
     }
 
     my $summary
-        = "$status: $name - "
-        . $dist->base_id() . ' - '
-        . $dist->author()->id();
+        = "$status: $name - " . $dist->base_id . ' - ' . $dist->author->id;
 
     if ($pm) {
         $pm->finish(
@@ -313,7 +313,7 @@ sub _test_report {
 sub _log_filename {
     my $type = shift;
 
-    return File::Spec->devnull()
+    return File::Spec->devnull
         unless $ENV{PERL_TEST_DM_LOG_DIR};
 
     return File::Spec->catfile(
@@ -329,11 +329,11 @@ sub _get_distro {
 
     return unless @mods == 1;
 
-    my $dist = $mods[0]->distribution();
+    my $dist = $mods[0]->distribution;
 
     return unless $dist;
 
-    $dist->get();
+    $dist->get;
 
     return $dist;
 }
@@ -349,20 +349,20 @@ sub _install_prereqs {
         .= " --install_base $install_dir";
     ## use critic
 
-    my $for_dist = $dist->base_id();
+    my $for_dist = $dist->base_id;
 
     for my $prereq ( $dist->unsat_prereq('configure_requires_later') ) {
         _install_prereq( $prereq->[0], $for_dist );
     }
 
-    $dist->undelay();
-    $dist->make();
+    $dist->undelay;
+    $dist->make;
 
     for my $prereq ( $dist->unsat_prereq('later') ) {
         _install_prereq( $prereq->[0], $for_dist );
     }
 
-    $dist->undelay();
+    $dist->undelay;
 }
 
 sub _install_prereq {
@@ -378,13 +378,13 @@ sub _install_prereq {
 
     _install_prereqs($dist);
 
-    my $installing = $dist->base_id();
+    my $installing = $dist->base_id;
 
     _prereq_log("Installing $installing for $for_dist\n");
 
     try {
-        $dist->notest();
-        $dist->install();
+        $dist->notest;
+        $dist->install;
     }
     catch {
         die "Installing $installing for $for_dist failed: $_";
@@ -490,7 +490,7 @@ sub _run_tests {
         require CPAN::Shell;
 
         ## no critic (InputOutput::RequireBriefOpen)
-        open my $fh, '>', File::Spec->devnull();
+        open my $fh, '>', File::Spec->devnull;
 
         {
             no warnings 'redefine';
@@ -500,7 +500,7 @@ sub _run_tests {
         ## no critic (Variables::ProhibitPackageVars)
         $CPAN::Be_Silent = 1;
 
-        CPAN::HandleConfig->load();
+        CPAN::HandleConfig->load;
         CPAN::Shell::setup_output();
         CPAN::Index->reload('force');
 
@@ -510,7 +510,7 @@ sub _run_tests {
         $CPAN::Config->{make_install_make_command} =~ s/^sudo //;
         $CPAN::Config->{mbuild_install_build_command} =~ s/^sudo //;
         $CPAN::Config->{make_install_arg} =~ s/UNINST=1//;
-        $CPAN::Config->{mbuild_install_arg} =~ s /--uninst\s+1//;
+        $CPAN::Config->{mbuild_install_arg} =~ s/--uninst\s+1//;
 
         if ( $ENV{PERL_TEST_DM_CPAN_VERBOSE} ) {
             $fh = io_from_write_cb( sub { $Test->diag( $_[0] ) } );
@@ -536,7 +536,7 @@ Test::DependentModules - Test all modules which depend on your module
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
